@@ -4,14 +4,12 @@
 /* ************************************************************************** */
 /* *                                                                        * */
 /* * project   : libmng                                                     * */
-/* * file      : libmng_callback_xs.c      copyright (c) 2000-2002 G.Juyn   * */
-/* * version   : 1.0.2                                                      * */
+/* * file      : libmng_callback_xs.c      copyright (c) 2000-2004 G.Juyn   * */
+/* * version   : 1.0.7                                                      * */
 /* *                                                                        * */
 /* * purpose   : callback get/set interface (implementation)                * */
 /* *                                                                        * */
 /* * author    : G.Juyn                                                     * */
-/* * web       : http://www.3-t.com                                         * */
-/* * email     : mailto:info@3-t.com                                        * */
 /* *                                                                        * */
 /* * comment   : implementation of the callback get/set functions           * */
 /* *                                                                        * */
@@ -43,6 +41,14 @@
 /* *             1.0.2 - 06/23/2001 - G.Juyn                                * */
 /* *             - added processterm callback                               * */
 /* *                                                                        * */
+/* *             1.0.6 - 07/07/2003 - G. R-P                                * */
+/* *             - added SKIPCHUNK feature                                  * */
+/* *                                                                        * */
+/* *             1.0.7 - 03/10/2004 - G.R-P                                 * */
+/* *             - added conditionals around openstream/closestream         * */
+/* *             1.0.7 - 03/19/2004 - G.R-P                                 * */
+/* *             - fixed typo (MNG_SKIPCHUNK_SAVE -> MNG_SKIPCHUNK_nEED     * */
+/* *                                                                        * */
 /* ************************************************************************** */
 
 #include "libmng.h"
@@ -106,6 +112,7 @@ mng_retcode MNG_DECL mng_setcb_memfree (mng_handle  hHandle,
 /* ************************************************************************** */
 
 #if defined(MNG_SUPPORT_READ) || defined(MNG_SUPPORT_WRITE)
+#ifndef MNG_NO_OPEN_CLOSE_STREAM
 mng_retcode MNG_DECL mng_setcb_openstream (mng_handle     hHandle,
                                            mng_openstream fProc)
 {
@@ -122,11 +129,13 @@ mng_retcode MNG_DECL mng_setcb_openstream (mng_handle     hHandle,
 
   return MNG_NOERROR;
 }
+#endif
 #endif /* MNG_SUPPORT_READ || MNG_SUPPORT_WRITE */
 
 /* ************************************************************************** */
 
 #if defined(MNG_SUPPORT_READ) || defined(MNG_SUPPORT_WRITE)
+#ifndef MNG_NO_OPEN_CLOSE_STREAM
 mng_retcode MNG_DECL mng_setcb_closestream (mng_handle      hHandle,
                                             mng_closestream fProc)
 {
@@ -143,6 +152,7 @@ mng_retcode MNG_DECL mng_setcb_closestream (mng_handle      hHandle,
 
   return MNG_NOERROR;
 }
+#endif
 #endif /* MNG_SUPPORT_READ || MNG_SUPPORT_WRITE */
 
 /* ************************************************************************** */
@@ -251,6 +261,7 @@ mng_retcode MNG_DECL mng_setcb_processheader (mng_handle        hHandle,
 /* ************************************************************************** */
 
 #ifdef MNG_SUPPORT_READ
+#ifndef MNG_SKIPCHUNK_tEXt
 mng_retcode MNG_DECL mng_setcb_processtext (mng_handle      hHandle,
                                             mng_processtext fProc)
 {
@@ -267,11 +278,13 @@ mng_retcode MNG_DECL mng_setcb_processtext (mng_handle      hHandle,
 
   return MNG_NOERROR;
 }
+#endif
 #endif /* MNG_SUPPORT_READ */
 
 /* ************************************************************************** */
 
 #ifdef MNG_SUPPORT_READ
+#ifndef MNG_SKIPCHUNK_SAVE
 mng_retcode MNG_DECL mng_setcb_processsave (mng_handle      hHandle,
                                             mng_processsave fProc)
 {
@@ -288,11 +301,13 @@ mng_retcode MNG_DECL mng_setcb_processsave (mng_handle      hHandle,
 
   return MNG_NOERROR;
 }
+#endif
 #endif /* MNG_SUPPORT_READ */
 
 /* ************************************************************************** */
 
 #ifdef MNG_SUPPORT_READ
+#ifndef MNG_SKIPCHUNK_SEEK
 mng_retcode MNG_DECL mng_setcb_processseek (mng_handle      hHandle,
                                             mng_processseek fProc)
 {
@@ -309,11 +324,13 @@ mng_retcode MNG_DECL mng_setcb_processseek (mng_handle      hHandle,
 
   return MNG_NOERROR;
 }
+#endif
 #endif /* MNG_SUPPORT_READ */
 
 /* ************************************************************************** */
 
 #ifdef MNG_SUPPORT_READ
+#ifndef MNG_SKIPCHUNK_nEED
 mng_retcode MNG_DECL mng_setcb_processneed (mng_handle      hHandle,
                                             mng_processneed fProc)
 {
@@ -330,6 +347,7 @@ mng_retcode MNG_DECL mng_setcb_processneed (mng_handle      hHandle,
 
   return MNG_NOERROR;
 }
+#endif
 #endif /* MNG_SUPPORT_READ */
 
 /* ************************************************************************** */
@@ -545,6 +563,7 @@ mng_retcode MNG_DECL mng_setcb_processgamma (mng_handle        hHandle,
 /* ************************************************************************** */
 
 #if defined(MNG_SUPPORT_DISPLAY) && defined(MNG_APP_CMS)
+#ifndef MNG_SKIPCHUNK_cHRM
 mng_retcode MNG_DECL mng_setcb_processchroma (mng_handle        hHandle,
                                               mng_processchroma fProc)
 {
@@ -561,6 +580,7 @@ mng_retcode MNG_DECL mng_setcb_processchroma (mng_handle        hHandle,
 
   return MNG_NOERROR;
 }
+#endif
 #endif /* MNG_SUPPORT_DISPLAY && MNG_APP_CMS */
 
 /* ************************************************************************** */
@@ -587,6 +607,7 @@ mng_retcode MNG_DECL mng_setcb_processsrgb (mng_handle      hHandle,
 /* ************************************************************************** */
 
 #if defined(MNG_SUPPORT_DISPLAY) && defined(MNG_APP_CMS)
+#ifndef MNG_SKIPCHUNK_iCCP
 mng_retcode MNG_DECL mng_setcb_processiccp (mng_handle      hHandle,
                                             mng_processiccp fProc)
 {
@@ -603,6 +624,7 @@ mng_retcode MNG_DECL mng_setcb_processiccp (mng_handle      hHandle,
 
   return MNG_NOERROR;
 }
+#endif
 #endif /* MNG_SUPPORT_DISPLAY && MNG_APP_CMS */
 
 /* ************************************************************************** */
@@ -690,6 +712,7 @@ mng_readdata MNG_DECL mng_getcb_readdata (mng_handle hHandle)
 /* ************************************************************************** */
 
 #if defined(MNG_SUPPORT_READ) || defined(MNG_SUPPORT_WRITE)
+#ifndef MNG_NO_OPEN_CLOSE_STREAM
 mng_openstream MNG_DECL mng_getcb_openstream (mng_handle hHandle)
 {
 #ifdef MNG_SUPPORT_TRACE
@@ -704,11 +727,13 @@ mng_openstream MNG_DECL mng_getcb_openstream (mng_handle hHandle)
 
   return ((mng_datap)hHandle)->fOpenstream;
 }
+#endif
 #endif /* MNG_SUPPORT_READ || MNG_SUPPORT_WRITE */
 
 /* ************************************************************************** */
 
 #if defined(MNG_SUPPORT_READ) || defined(MNG_SUPPORT_WRITE)
+#ifndef MNG_NO_OPEN_CLOSE_STREAM
 mng_closestream MNG_DECL mng_getcb_closestream (mng_handle hHandle)
 {
 #ifdef MNG_SUPPORT_TRACE
@@ -723,6 +748,7 @@ mng_closestream MNG_DECL mng_getcb_closestream (mng_handle hHandle)
 
   return ((mng_datap)hHandle)->fClosestream;
 }
+#endif
 #endif /* MNG_SUPPORT_READ || MNG_SUPPORT_WRITE */
 
 /* ************************************************************************** */
@@ -802,6 +828,7 @@ mng_processheader MNG_DECL mng_getcb_processheader (mng_handle hHandle)
 /* ************************************************************************** */
 
 #ifdef MNG_SUPPORT_READ
+#ifndef MNG_SKIPCHUNK_tEXt
 mng_processtext MNG_DECL mng_getcb_processtext (mng_handle hHandle)
 {
 #ifdef MNG_SUPPORT_TRACE
@@ -816,11 +843,13 @@ mng_processtext MNG_DECL mng_getcb_processtext (mng_handle hHandle)
 
   return ((mng_datap)hHandle)->fProcesstext;
 }
+#endif
 #endif /* MNG_SUPPORT_READ */
 
 /* ************************************************************************** */
 
 #ifdef MNG_SUPPORT_READ
+#ifndef MNG_SKIPCHUNK_SAVE
 mng_processsave MNG_DECL mng_getcb_processsave (mng_handle hHandle)
 {
 #ifdef MNG_SUPPORT_TRACE
@@ -835,11 +864,13 @@ mng_processsave MNG_DECL mng_getcb_processsave (mng_handle hHandle)
 
   return ((mng_datap)hHandle)->fProcesssave;
 }
+#endif
 #endif /* MNG_SUPPORT_READ */
 
 /* ************************************************************************** */
 
 #ifdef MNG_SUPPORT_READ
+#ifndef MNG_SKIPCHUNK_SEEK
 mng_processseek MNG_DECL mng_getcb_processseek (mng_handle hHandle)
 {
 #ifdef MNG_SUPPORT_TRACE
@@ -854,11 +885,13 @@ mng_processseek MNG_DECL mng_getcb_processseek (mng_handle hHandle)
 
   return ((mng_datap)hHandle)->fProcessseek;
 }
+#endif
 #endif /* MNG_SUPPORT_READ */
 
 /* ************************************************************************** */
 
 #ifdef MNG_SUPPORT_READ
+#ifndef MNG_SKIPCHUNK_nEED
 mng_processneed MNG_DECL mng_getcb_processneed (mng_handle hHandle)
 {
 #ifdef MNG_SUPPORT_TRACE
@@ -873,6 +906,7 @@ mng_processneed MNG_DECL mng_getcb_processneed (mng_handle hHandle)
 
   return ((mng_datap)hHandle)->fProcessneed;
 }
+#endif
 #endif /* MNG_SUPPORT_READ */
 
 /* ************************************************************************** */
@@ -1068,6 +1102,7 @@ mng_processgamma MNG_DECL mng_getcb_processgamma (mng_handle hHandle)
 /* ************************************************************************** */
 
 #if defined(MNG_SUPPORT_DISPLAY) && defined(MNG_APP_CMS)
+#ifndef MNG_SKIPCHUNK_cHRM
 mng_processchroma MNG_DECL mng_getcb_processchroma (mng_handle hHandle)
 {
 #ifdef MNG_SUPPORT_TRACE
@@ -1082,6 +1117,7 @@ mng_processchroma MNG_DECL mng_getcb_processchroma (mng_handle hHandle)
 
   return ((mng_datap)hHandle)->fProcesschroma;
 }
+#endif
 #endif /* MNG_SUPPORT_DISPLAY && MNG_APP_CMS */
 
 /* ************************************************************************** */
@@ -1106,6 +1142,7 @@ mng_processsrgb MNG_DECL mng_getcb_processsrgb (mng_handle hHandle)
 /* ************************************************************************** */
 
 #if defined(MNG_SUPPORT_DISPLAY) && defined(MNG_APP_CMS)
+#ifndef MNG_SKIPCHUNK_iCCP
 mng_processiccp MNG_DECL mng_getcb_processiccp (mng_handle hHandle)
 {
 #ifdef MNG_SUPPORT_TRACE
@@ -1120,6 +1157,7 @@ mng_processiccp MNG_DECL mng_getcb_processiccp (mng_handle hHandle)
 
   return ((mng_datap)hHandle)->fProcessiccp;
 }
+#endif
 #endif /* MNG_SUPPORT_DISPLAY && MNG_APP_CMS */
 
 /* ************************************************************************** */
